@@ -2,7 +2,7 @@
 from .api.config import Config
 from .errors import APIError, ConfigurationError, ArgumentMissingError
 
-from .api.activity import Activity
+from .api.customers.activity import CustomerActivity
 from .api.attributes import Attributes
 from .api.custom_attrs import CustomAttributes
 from .api.customer import Customer
@@ -12,10 +12,11 @@ from .api.metrics import Metrics
 from .api.ping import Ping
 from .api.plan import Plan
 from .api.plan_group import PlanGroup
-from .api.subscription import Subscription
+from .api.customers.subscription import CustomerSubscription
 from .api.tags import Tags
 from .api.transaction import Transaction
 from .api.account import Account
+from .api.activity import Activity
 
 # Deprecated
 import imp
@@ -31,7 +32,7 @@ Provides convenient Python bindings for ChartMogul's API.
 """
 
 __title__ = 'chartmogul'
-__version__ = '1.6.2'
+__version__ = '2.0.0'
 __build__ = 0x000000
 __author__ = 'ChartMogul Ltd'
 __license__ = 'MIT'
